import { SocketEvent } from '@/socket/socket-event';
import { Config, IDictionary, IEventParam } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { io, Socket } from 'socket.io-client';

export class MainGridController {
  public socket?: Socket;

  public prevSalary: IDictionary<number> = {};

  public salaryClass({ row }: IDictionary<any>) {
    if (row.salary > this.prevSalary[row.id]) {
      return 'increase-animation';
    }

    if (row.salary < this.prevSalary[row.id]) {
      return 'decrease-animation';
    }

    return '';
  }

  public gridMounted({ component }: IEventParam<TekGrid>) {
    this.socket = io(Config.endPoint, {
      transports: ['websocket', 'polling'],
    });

    this.socket.off(SocketEvent.CONNECTION)
      .on(SocketEvent.CONNECTION, (employees: IDictionary[]) => {
        component.datasource.updateData(employees);

        employees.forEach((emp) => {
          this.prevSalary[emp.id] = emp.salary || 0;
        });
      });

    this.socket.off(SocketEvent.EMPLOYEE_CHANGED)
      .on(SocketEvent.EMPLOYEE_CHANGED, async (employee: IDictionary) => {
        await component.datasource.put(employee);
        await component.datasource.get();
        component.reapplyConditions(employee);

        this.prevSalary[employee.id] = employee.salary;
      });
  }

  public gridBeforeDestroy() {
    this.socket?.disconnect();
  }
}
