import { AlertService, LoadingService } from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class VersionController {
    public getIsVisibleApprove({ row }: any) {
        return row.IDAPROVVER === 'S';
    }

    public getIsVisibleRemove({ row }: any) {
        return row.IDAPROVVER === 'N';
    }

    public approveVersion({ row }: any) {
        const grid = Metadata.getInstance<TekGrid>('version-grid');

        const isApprove = row.IDAPROVVER === 'N';
        const params = {
            ID: row.ID,
            IDAPROVVER: isApprove ? 'S' : 'N',
        };

        LoadingService.show();
        Http.put('updateUpdaterProdVersaoAprov', params).then(() => {
            LoadingService.hide();

            grid.datasource.data.map((datasource) => {
                if (datasource.ID === params.ID) {
                    datasource.IDAPROVVER = params.IDAPROVVER;
                }

                return true;
            });

            grid.datasource.get();

            const message = isApprove ? 'Versão aprovada com sucesso!' : 'Aprovação removida com sucesso!';
            this.showAlert(message, 'success');
        }).catch((error) => {
            LoadingService.hide();
            this.showAlert(error, 'error');
        });
    }

    private showAlert(message: string | any, colorStr: string) {
        AlertService.show({
            name: 'info-alert',
            text: message,
            color: colorStr,
            right: true,
            top: true,
            showDismiss: true,
            timeout: 5000,
        });
    }

    public async gridMounted() {
        const grid = Metadata.getInstance<TekGrid>('version-grid');

        try {
          grid.datasource.loading = true;

          const versionConfig = await Http.get('/updaterProdutosVersaoConfig');

          grid.datasource.updateData(versionConfig.data.data);
          grid.datasource.loading = false;
        } catch (error) {
          grid.datasource.loading = false;
          this.showAlert(error, 'error');
        }
      }
}
